<?php

namespace Drupal\gleab\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Cache\Cache;
use Drupal\Core\Render\Markup;
use Drupal\Core\Url;
use Drupal\Core\Link;

/**
 * Provides a Gleab block.
 * @Block( id = "gleab_block",
 * admin_label = @Translation("Gleab Block"),
 * category = @Translation("Custom block")
 * )
 */
class GleabBlock extends BlockBase {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = \Drupal::config('gleab.gleab_configuration');
    if (empty($config->get('gleab_api_key'))) {
      if (\Drupal::currentUser()->hasPermission('administer gleab')) {
        $url = Url::fromUri('route:gleab_configuration');
        $link = new Link(t('here'), $url);
        $link = $link->toString()->getGeneratedLink();
        \Drupal::messenger()->addError(Markup::create(t('Please fill out the Gleap API key from') . " " . $link));
      }
      return;
    }
    else {
      $script = Markup::create('<script>!function(Gleap,t,i){if(!(Gleap=window.Gleap=window.Gleap||[]).invoked){for(window.GleapActions=[],Gleap.invoked=!0,Gleap.methods=["identify","clearIdentity","attachCustomData","setCustomData","removeCustomData","clearCustomData","registerCustomAction","logEvent","sendSilentCrashReport","startFeedbackFlow","setAppBuildNumber","setAppVersionCode","preFillForm","setApiUrl","setFrameUrl","isOpened","open","close","on","setLanguage","setOfflineMode","initialize"],Gleap.f=function(e){return function(){var t=Array.prototype.slice.call(arguments);window.GleapActions.push({e:e,a:t})}},t=0;t<Gleap.methods.length;t++)Gleap[i=Gleap.methods[t]]=Gleap.f(i);Gleap.load=function(){var t=document.getElementsByTagName("head")[0],i=document.createElement("script");i.type="text/javascript",i.async=!0,i.src="https://js.gleap.io/latest/index.js",t.appendChild(i)},Gleap.load(), Gleap.initialize("' . $config->get('gleab_api_key') . '") }}();</script>');
    }
    return [
      '#markup' => $script,
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheTags() {
    // Return default tags instead.
    return parent::getCacheTags();
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheContexts() {
    return Cache::mergeContexts(parent::getCacheContexts(), ['route']);
  }

}
